@@ -181,7 +181,7 @@ extern const char	*_ppdCacheGetOutputBin(_ppd_cache_t *pc,
 extern const char	*_ppdCacheGetPageSize(_ppd_cache_t *pc, ipp_t *job,
 			                      const char *keyword, int *exact) _CUPS_PRIVATE;
 extern pwg_size_t	*_ppdCacheGetSize(_ppd_cache_t *pc,
-			                  const char *page_size) _CUPS_PRIVATE;
+			                  const char *page_size, ppd_size_t *ppd_size) _CUPS_PRIVATE;
 extern const char	*_ppdCacheGetSource(_ppd_cache_t *pc,
 			                    const char *input_slot) _CUPS_PRIVATE;
 extern const char	*_ppdCacheGetType(_ppd_cache_t *pc,
