@@ -1,16 +1,11 @@
 /*
  * Internationalization test for CUPS.
  *
+ * Copyright © 2020-2024 by OpenPrinting.
  * Copyright 2007-2014 by Apple Inc.
  * Copyright 1997-2006 by Easy Software Products.
  *
- * These coded instructions, statements, and computer programs are the
- * property of Apple Inc. and are protected by Federal copyright
- * law.  Distribution and use rights are outlined in the file "LICENSE.txt"
- * which should have been included with this file.  If this file is
- * missing or damaged, see the license at "http://www.cups.org/".
- *
- * This file is subject to the Apple OS-Developed Software exception.
+ * Licensed under Apache License v2.0.  See the file "LICENSE" for more information.
  */
 
 /*
@@ -173,6 +168,7 @@ main(int  argc,				/* I - Argument Count */
     if (encoding == CUPS_AUTO_ENCODING)
     {
       fprintf(stderr, "%s: Unknown character set!\n", argv[2]);
+      fclose(fp);
       return (1);
     }
 
@@ -181,6 +177,7 @@ main(int  argc,				/* I - Argument Count */
       if (cupsCharsetToUTF8(utf8dest, line, sizeof(utf8dest), encoding) < 0)
       {
         fprintf(stderr, "%s: Unable to convert line: %s", argv[1], line);
+        fclose(fp);
 	return (1);
       }
 
@@ -416,7 +413,7 @@ main(int  argc,				/* I - Argument Count */
       puts("PASS");
   }
 
-#ifndef __linux
+#if 0 // Appears to be broken on all OS's
   fputs("cupsCharsetToUTF8(CUPS_EUC_JP): ", stdout);
 
   strlcpy(legsrc, legdest, sizeof(legsrc));
@@ -438,7 +435,7 @@ main(int  argc,				/* I - Argument Count */
   }
   else
     puts("PASS");
-#endif /* !__linux */
+#endif /* 0 */
 
  /*
   * Test UTF-8 to/from legacy charset (Windows 950)...
