@@ -895,7 +895,7 @@ main(int  argc,			/* I - Number of command-line arguments */
 
       if (request)
       {
-	printf("\n%s:\n", argv[i]);
+	printf("\n%s: %s\n", argv[i], ippValidateAttributes(request) ? "OK" : cupsLastErrorString());
 	print_attributes(request, 4);
 	ippDelete(request);
       }
